package rocketapi.sp.config;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.web.client.RestTemplate;

import com.github.alenfive.rocketapi.service.LoginService;

import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import rocketapi.sp.auth.JwtTokenLoginService;

@Configuration
@Slf4j
public class Config {

    @Bean
    @Primary
    public RestTemplate createRestTemplate() {
        log.debug("create RestTemplate");
        return new RestTemplate();
    }

    @Bean
    @Primary
    public LoginService createLoginService() {
        return new JwtTokenLoginService();
    }

	@Getter
	@Value("${jwt.secret:a-public-key-for-sp0O}")
	private String key;

	@Getter
	@Value("${jwt.url:http://localhost:3000/auth}")
	private String loginUrl;

	@Getter
	@Value("${jwt.header.key.token:rocket-user-token}")
	private String headerTokenKey;

	@Getter
	@Value("${jwt.claim.key.user:UserInfo}")
	private String claimUserKey;

	@Getter
	@Value("${jwt.user-info.key.username:username}")
	private String usernameKey;
	@Getter
	@Value("${jwt.user-info.key.nickname:name}")
	private String nicknameKey;
	@Getter
	@Value("${jwt.user-info.key.metadata:metadata}")
	private String metadataKey;
	@Getter
	@Value("${jwt.user-info.key.metadata-avatar:avatar}")
	private String avatarKey;
	@Getter
	@Value("${jwt.user-info.key.metadata-authorities:authorities}")
	private String authoritiesKey;
}
